@@ -16,6 +16,7 @@
 from __future__ import print_function, absolute_import
 
 import re
+import webbrowser
 
 from collections import OrderedDict
 
@@ -123,6 +124,11 @@ class Command(BaseCommand):
                  "the URL at which you can later get information about the "
                  "measurement."
         )
+        self.parser.add_argument(
+            "--go-web",
+            action="store_true",
+            help="Open the measurement in a webbrowser immediately."
+        )
         self.parser.add_argument(
             "--set-alias",
             help="After creating the measurement, register an alias for it.",
@@ -230,6 +236,10 @@ class Command(BaseCommand):
             default=conf["specification"]["resolve_on_probe"],
             help="Causes the target to be resolved by each probe rather than once by the server",
         )
+        self.parser.add_argument(
+            "--measurement-tags",
+            help="Comma-separated list of tags to apply to the newly created measurement",
+        )
 
         Renderer.add_arguments_for_available_renderers(self.parser)
 
@@ -252,6 +262,15 @@ class Command(BaseCommand):
             "Looking good!  Your measurement was created and details about "
             "it can be found here:\n\n  {0}".format(url)
         )
+        if self.arguments.go_web:
+            self.ok(
+                "Opening the url in the browser\n\n "
+            )
+            if not webbrowser.open(url):
+                self.ok(
+                    "It looks like your system doesn't have a web browser "
+                    "available.  You'll have to go there manually: {0}".format(url)
+                    )
 
         if self.arguments.set_alias:
             alias = self.arguments.set_alias
@@ -344,6 +363,10 @@ class Command(BaseCommand):
                 "these, a measurement cannot be created."
             )
 
+        if self.arguments.measurement_tags:
+            tags = self.arguments.measurement_tags.split(",")
+            r["tags"] = tags
+
         if target:
             r["target"] = target
 
@@ -440,6 +463,18 @@ class Command(BaseCommand):
         if isinstance(response, dict) and "detail" in response:
             error_detail = response["detail"]
 
+            if response.get("error", {}).get("status") == 403:
+                message = (
+                    "There was a problem communicating with the RIPE Atlas "
+                    "infrastructure. \nStatus is 403 so you probably need an API "
+                    "key. Register and create API Keys at "
+                    "https://atlas.ripe.net/\n"
+                    "Create the new key with the permission Create a new user "
+                    "defined measurement and install using:\n\n"
+                    "   ripe-atlas configure --set authorisation.create=MY_API_KEY\n\n"
+                    "The message given was:\n\n  {}"
+                ).format(error_detail)
+
         message = (
             "There was a problem communicating with the RIPE Atlas "
             "infrastructure.  The message given was:\n\n  {}"
