@@ -239,7 +239,7 @@ class Command(TabularFieldsMixin, BaseCommand):
         else:
 
             for probe in truncated_probes:
-                print(self._get_line(probe))
+                print(self._get_line(probe).encode("utf8"))
 
         print(colourise(hr, "bold"))
 
@@ -272,8 +272,7 @@ class Command(TabularFieldsMixin, BaseCommand):
         elif isinstance(aggregation_data, list):
 
             for index, probe in enumerate(aggregation_data):
-                print(" ", end="")
-                print(self._get_line(probe))
+                print(" {}".format(self._get_line(probe)).encode("utf8"))
                 if self.arguments.max_per_aggregation:
                     if index >= self.arguments.max_per_aggregation - 1:
                         break
@@ -511,24 +510,16 @@ class Command(TabularFieldsMixin, BaseCommand):
 
     def _get_line(self, probe):
         """
-        Python 2 and 3 differ on how to render strings with non-ascii characters
-        in them, so we have to accommodate both here.
+        Returns a utf8 encode string safe for printing and outputing
+        to files.
         """
-
-        if six.PY2:
-
-            return colourise(
-                self._get_line_format().format(
-                    *self._get_line_items(probe)
-                ).encode("utf-8"),
-                self._get_colour_from_status(probe.status)
-            )
-
-        return colourise(
+        log = colourise(
             self._get_line_format().format(*self._get_line_items(probe)),
             self._get_colour_from_status(probe.status)
         )
 
+        return log
+
     def _get_filter_key_value_pair(self, k, v):
         if k == "country_code":
             return "Country", v.upper()
