@@ -14,6 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
+import six
 COLOURS_AVAILABLE = False
 try:
     # We use curses to detect ANSI colour support
@@ -37,7 +38,11 @@ class Colour(object):
 
     @classmethod
     def _colourise(cls, text, colour):
-        return "{}[{}m{}{}[0m".format(chr(0x1b), colour, text, chr(0x1b))
+        # Make sure we don't mix unicode and strings
+        if six.PY2 and isinstance(text, six.string_types):
+            text = unicode(text)
+
+        return u"{}[{}m{}{}[0m".format(chr(0x1b), colour, text, chr(0x1b))
 
     @classmethod
     def black(cls, text):
